@@ -20,17 +20,16 @@ package main
 import (
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"reflect"
 	"strings"
 
-	"github.com/apache/camel-k/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/util"
 
 	apiextensionsv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
 	clientscheme "k8s.io/client-go/kubernetes/scheme"
 
-	"github.com/apache/camel-k/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 )
 
 func main() {
@@ -99,7 +98,7 @@ func generate(crdFilename, dslFilename, path string, isArray bool, destination s
 	if err != nil {
 		return err
 	}
-	return ioutil.WriteFile(destination, result, 0o600)
+	return os.WriteFile(destination, result, 0o600)
 }
 
 func remapRef(ref string) string {
@@ -112,11 +111,17 @@ func rebaseRefs(schema map[string]interface{}) {
 		case k == "$ref" && reflect.TypeOf(v).Kind() == reflect.String:
 			schema[k] = remapRef(fmt.Sprintf("%v", v))
 		case reflect.TypeOf(v).Kind() == reflect.Map:
-			rebaseRefs(v.(map[string]interface{}))
+			if m, ok := v.(map[string]interface{}); ok {
+				rebaseRefs(m)
+			}
 		case reflect.TypeOf(v).Kind() == reflect.Slice:
-			for _, vv := range v.([]interface{}) {
-				if reflect.TypeOf(vv).Kind() == reflect.Map {
-					rebaseRefs(vv.(map[string]interface{}))
+			if vs, ok := v.([]interface{}); ok {
+				for _, vv := range vs {
+					if reflect.TypeOf(vv).Kind() == reflect.Map {
+						if m, ok := vv.(map[string]interface{}); ok {
+							rebaseRefs(m)
+						}
+					}
 				}
 			}
 		}
