@@ -35,11 +35,12 @@ import (
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
 	routev1 "github.com/openshift/api/route/v1"
+	olm "github.com/operator-framework/api/pkg/operators/v1alpha1"
 
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/client/camel/clientset/versioned"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
-	"github.com/apache/camel-k/pkg/util/openshift"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/client/camel/clientset/versioned"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/openshift"
 )
 
 // Dump prints all information about the given namespace to debug errors
@@ -50,20 +51,8 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 	if err != nil {
 		return err
 	}
-	pls, err := camelClient.CamelV1().IntegrationPlatforms(ns).List(ctx, metav1.ListOptions{})
-	if err != nil {
-		return err
-	}
-	t.Logf("Found %d platforms:\n", len(pls.Items))
-	for _, p := range pls.Items {
-		ref := p
-		pdata, err := kubernetes.ToYAMLNoManagedFields(&ref)
-		if err != nil {
-			return err
-		}
-		t.Logf("---\n%s\n---\n", string(pdata))
-	}
 
+	// Integrations
 	its, err := camelClient.CamelV1().Integrations(ns).List(ctx, metav1.ListOptions{})
 	if err != nil {
 		return err
@@ -78,6 +67,7 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 		t.Logf("---\n%s\n---\n", string(pdata))
 	}
 
+	// IntegrationKits
 	iks, err := camelClient.CamelV1().IntegrationKits(ns).List(ctx, metav1.ListOptions{})
 	if err != nil {
 		return err
@@ -92,6 +82,7 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 		t.Logf("---\n%s\n---\n", string(pdata))
 	}
 
+	// Builds
 	builds, err := camelClient.CamelV1().Builds(ns).List(ctx, metav1.ListOptions{})
 	if err != nil {
 		return err
@@ -105,6 +96,7 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 		t.Logf("---\n%s\n---\n", string(data))
 	}
 
+	// Configmaps
 	cms, err := c.CoreV1().ConfigMaps(ns).List(ctx, metav1.ListOptions{})
 	if err != nil {
 		return err
@@ -119,11 +111,12 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 		t.Logf("---\n%s\n---\n", string(pdata))
 	}
 
+	// Deployments
 	deployments, err := c.AppsV1().Deployments(ns).List(ctx, metav1.ListOptions{})
 	if err != nil {
 		return err
 	}
-	t.Logf("Found %d deployments:\n", len(iks.Items))
+	t.Logf("Found %d deployments:\n", len(deployments.Items))
 	for _, deployment := range deployments.Items {
 		ref := deployment
 		data, err := kubernetes.ToYAMLNoManagedFields(&ref)
@@ -133,6 +126,22 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 		t.Logf("---\n%s\n---\n", string(data))
 	}
 
+	// PVCs
+	pvcs, err := c.CoreV1().PersistentVolumeClaims(ns).List(ctx, metav1.ListOptions{})
+	if err != nil {
+		return err
+	}
+	t.Logf("Found %d persistent volume claims:\n", len(pvcs.Items))
+	for _, pvc := range pvcs.Items {
+		ref := pvc
+		pdata, err := kubernetes.ToYAMLNoManagedFields(&ref)
+		if err != nil {
+			return err
+		}
+		t.Logf("---\n%s\n---\n", string(pdata))
+	}
+
+	// Pods
 	lst, err := c.CoreV1().Pods(ns).List(ctx, metav1.ListOptions{})
 	if err != nil {
 		return err
@@ -164,6 +173,37 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 		}
 	}
 
+	// IntegrationPlatforms
+	pls, err := camelClient.CamelV1().IntegrationPlatforms(ns).List(ctx, metav1.ListOptions{})
+	if err != nil {
+		return err
+	}
+	t.Logf("Found %d platforms:\n", len(pls.Items))
+	for _, p := range pls.Items {
+		ref := p
+		pdata, err := kubernetes.ToYAMLNoManagedFields(&ref)
+		if err != nil {
+			return err
+		}
+		t.Logf("---\n%s\n---\n", string(pdata))
+	}
+
+	// CamelCatalogs
+	cats, err := camelClient.CamelV1().CamelCatalogs(ns).List(ctx, metav1.ListOptions{})
+	if err != nil {
+		return err
+	}
+	t.Logf("Found %d catalogs:\n", len(cats.Items))
+	for _, c := range cats.Items {
+		ref := c
+		cdata, err := kubernetes.ToYAMLNoManagedFields(&ref)
+		if err != nil {
+			return err
+		}
+		t.Logf("---\n%s\n---\n", string(cdata))
+	}
+
+	// Services
 	svcs, err := c.CoreV1().Services(ns).List(ctx, metav1.ListOptions{})
 	if err != nil {
 		return err
@@ -178,6 +218,7 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 		t.Logf("---\n%s\n---\n", string(data))
 	}
 
+	// Routes
 	if ocp, err := openshift.IsOpenShift(c); err == nil && ocp {
 		routes := routev1.RouteList{
 			TypeMeta: metav1.TypeMeta{
@@ -200,6 +241,24 @@ func Dump(ctx context.Context, c client.Client, ns string, t *testing.T) error {
 		}
 	}
 
+	// OLM CSV
+	csvs := olm.ClusterServiceVersionList{}
+	err = c.List(ctx, &csvs, ctrl.InNamespace(ns))
+	if err != nil {
+		return err
+	}
+	t.Logf("\nFound %d OLM CSVs:\n", len(csvs.Items))
+	for _, csv := range csvs.Items {
+		ref := csv
+		data, err := kubernetes.ToYAMLNoManagedFields(&ref)
+		if err != nil {
+			return err
+		}
+		t.Logf("---\n%s\n---\n", string(data))
+	}
+
+	// Some log from running pods
+
 	//
 	// Get logs for global operator if it is being used
 	//
@@ -258,7 +317,7 @@ func dumpLogs(ctx context.Context, c client.Client, prefix string, ns string, na
 
 	if os.Getenv("CAMEL_K_TEST_LOG_LEVEL") != "debug" {
 		// If not in debug mode then curtail the dumping of log lines
-		lines := int64(50)
+		lines := int64(150)
 		logOptions.TailLines = &lines
 	}
 
