@@ -23,15 +23,14 @@ import (
 	"compress/gzip"
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"os"
 	"path/filepath"
 	"strings"
-	"time"
 
 	corev1 "k8s.io/api/core/v1"
-	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime/schema"
@@ -39,17 +38,15 @@ import (
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/client/apiutil"
-	ctrlutil "sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
-
-	"github.com/pkg/errors"
 
 	buildv1 "github.com/openshift/api/build/v1"
 	imagev1 "github.com/openshift/api/image/v1"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/util"
-	"github.com/apache/camel-k/pkg/util/log"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/util/log"
+	"github.com/apache/camel-k/v2/pkg/util/s2i"
 )
 
 type s2iTask struct {
@@ -91,11 +88,6 @@ func (t *s2iTask) Do(ctx context.Context) v1.BuildStatus {
 		},
 	}
 
-	err := t.c.Delete(ctx, bc)
-	if err != nil && !apierrors.IsNotFound(err) {
-		return status.Failed(errors.Wrap(err, "cannot delete build config"))
-	}
-
 	// Set the build controller as owner reference
 	owner := t.getControllerReference()
 	if owner == nil {
@@ -103,13 +95,9 @@ func (t *s2iTask) Do(ctx context.Context) v1.BuildStatus {
 		owner = t.build
 	}
 
-	if err := ctrlutil.SetOwnerReference(owner, bc, t.c.GetScheme()); err != nil {
-		return status.Failed(errors.Wrapf(err, "cannot set owner reference on BuildConfig: %s", bc.Name))
-	}
-
-	err = t.c.Create(ctx, bc)
+	err := s2i.BuildConfig(ctx, t.c, bc, owner)
 	if err != nil {
-		return status.Failed(errors.Wrap(err, "cannot create build config"))
+		return status.Failed(err)
 	}
 
 	is := &imagev1.ImageStream{
@@ -129,18 +117,9 @@ func (t *s2iTask) Do(ctx context.Context) v1.BuildStatus {
 		},
 	}
 
-	err = t.c.Delete(ctx, is)
-	if err != nil && !apierrors.IsNotFound(err) {
-		return status.Failed(errors.Wrap(err, "cannot delete image stream"))
-	}
-
-	if err := ctrlutil.SetOwnerReference(owner, is, t.c.GetScheme()); err != nil {
-		return status.Failed(errors.Wrapf(err, "cannot set owner reference on ImageStream: %s", is.Name))
-	}
-
-	err = t.c.Create(ctx, is)
+	err = s2i.ImageStream(ctx, t.c, is, owner)
 	if err != nil {
-		return status.Failed(errors.Wrap(err, "cannot create image stream"))
+		return status.Failed(err)
 	}
 
 	err = util.WithTempDir(t.build.Name+"-s2i-", func(tmpDir string) error {
@@ -161,12 +140,12 @@ func (t *s2iTask) Do(ctx context.Context) v1.BuildStatus {
 
 		archiveFile, err := os.Create(archive)
 		if err != nil {
-			return errors.Wrap(err, "cannot create tar archive")
+			return fmt.Errorf("cannot create tar archive: %w", err)
 		}
 
 		err = tarDir(contextDir, archiveFile)
 		if err != nil {
-			return errors.Wrap(err, "cannot tar context directory")
+			return fmt.Errorf("cannot tar context directory: %w", err)
 		}
 
 		f, err := util.Open(archive)
@@ -190,25 +169,25 @@ func (t *s2iTask) Do(ctx context.Context) v1.BuildStatus {
 			Do(ctx)
 
 		if r.Error() != nil {
-			return errors.Wrap(r.Error(), "cannot instantiate binary")
+			return fmt.Errorf("cannot instantiate binary: %w", r.Error())
 		}
 
 		data, err := r.Raw()
 		if err != nil {
-			return errors.Wrap(err, "no raw data retrieved")
+			return fmt.Errorf("no raw data retrieved: %w", err)
 		}
 
 		s2iBuild := buildv1.Build{}
 		err = json.Unmarshal(data, &s2iBuild)
 		if err != nil {
-			return errors.Wrap(err, "cannot unmarshal instantiated binary response")
+			return fmt.Errorf("cannot unmarshal instantiated binary response: %w", err)
 		}
 
-		err = t.waitForS2iBuildCompletion(ctx, t.c, &s2iBuild)
+		err = s2i.WaitForS2iBuildCompletion(ctx, t.c, &s2iBuild)
 		if err != nil {
 			if errors.Is(err, context.Canceled) || errors.Is(err, context.DeadlineExceeded) {
 				// nolint: contextcheck
-				if err := t.cancelBuild(context.Background(), &s2iBuild); err != nil {
+				if err := s2i.CancelBuild(context.Background(), t.c, &s2iBuild); err != nil {
 					log.Errorf(err, "cannot cancel s2i Build: %s/%s", s2iBuild.Namespace, s2iBuild.Name)
 				}
 			}
@@ -256,44 +235,6 @@ func (t *s2iTask) getControllerReference() metav1.Object {
 	return owner
 }
 
-func (t *s2iTask) waitForS2iBuildCompletion(ctx context.Context, c client.Client, build *buildv1.Build) error {
-	key := ctrl.ObjectKeyFromObject(build)
-	for {
-		select {
-
-		case <-ctx.Done():
-			return ctx.Err()
-
-		case <-time.After(1 * time.Second):
-			err := c.Get(ctx, key, build)
-			if err != nil {
-				if apierrors.IsNotFound(err) {
-					continue
-				}
-				return err
-			}
-
-			if build.Status.Phase == buildv1.BuildPhaseComplete {
-				return nil
-			} else if build.Status.Phase == buildv1.BuildPhaseCancelled ||
-				build.Status.Phase == buildv1.BuildPhaseFailed ||
-				build.Status.Phase == buildv1.BuildPhaseError {
-				return errors.New("build failed")
-			}
-		}
-	}
-}
-
-func (t *s2iTask) cancelBuild(ctx context.Context, build *buildv1.Build) error {
-	target := build.DeepCopy()
-	target.Status.Cancelled = true
-	if err := t.c.Patch(ctx, target, ctrl.MergeFrom(build)); err != nil {
-		return err
-	}
-	*build = *target
-	return nil
-}
-
 func tarDir(src string, writers ...io.Writer) error {
 	// ensure the src actually exists before trying to tar it
 	if _, err := os.Stat(src); err != nil {
