@@ -27,7 +27,7 @@ import (
 
 	"github.com/spf13/cobra"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 )
 
 type getCmdOptions struct {
