@@ -19,9 +19,10 @@ package cmd
 
 import (
 	"context"
+	"errors"
 	"fmt"
+	"time"
 
-	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 
@@ -33,9 +34,11 @@ import (
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 	"sigs.k8s.io/controller-runtime/pkg/client/apiutil"
 
-	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/util/olm"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/apache/camel-k/v2/pkg/util/olm"
+	"github.com/apache/camel-k/v2/pkg/util/watch"
 )
 
 func newCmdUninstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *uninstallCmdOptions) {
@@ -62,6 +65,7 @@ func newCmdUninstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *uninstall
 	cmd.Flags().Bool("skip-config-maps", false, "Do not uninstall the Camel K Config Maps in the current namespace")
 	cmd.Flags().Bool("skip-registry-secret", false, "Do not uninstall the Camel K Registry Secret in the current namespace")
 	cmd.Flags().Bool("skip-kamelets", false, "Do not uninstall the Kamelets in the current namespace")
+	cmd.Flags().Bool("skip-camel-catalogs", false, "Do not uninstall the Camel Catalogs in the current namespace")
 	cmd.Flags().Bool("global", false, "Indicates that a global installation is going to be uninstalled (affects OLM)")
 	cmd.Flags().Bool("olm", true, "Try to uninstall via OLM (Operator Lifecycle Manager) if available")
 	cmd.Flags().String("olm-operator-name", "", "Name of the Camel K operator in the OLM source or marketplace")
@@ -86,6 +90,7 @@ type uninstallCmdOptions struct {
 	SkipConfigMaps          bool `mapstructure:"skip-config-maps"`
 	SkipRegistrySecret      bool `mapstructure:"skip-registry-secret"`
 	SkipKamelets            bool `mapstructure:"skip-kamelets"`
+	SkipCamelCatalogs       bool `mapstructure:"skip-camel-catalogs"`
 	Global                  bool `mapstructure:"global"`
 	OlmEnabled              bool `mapstructure:"olm"`
 	UninstallAll            bool `mapstructure:"all"`
@@ -132,7 +137,7 @@ func (o *uninstallCmdOptions) uninstall(cmd *cobra.Command, _ []string) error {
 	if o.OlmEnabled {
 		var err error
 		if uninstallViaOLM, err = olm.IsAPIAvailable(o.Context, c, o.Namespace); err != nil {
-			return errors.Wrap(err, "error while checking OLM availability. Run with '--olm=false' to skip this check")
+			return fmt.Errorf("error while checking OLM availability. Run with '--olm=false' to skip this check: %w", err)
 		}
 
 		if uninstallViaOLM {
@@ -154,6 +159,19 @@ func (o *uninstallCmdOptions) uninstall(cmd *cobra.Command, _ []string) error {
 				return err
 			}
 			fmt.Fprintf(cmd.OutOrStdout(), "Camel K Operator removed from namespace %s\n", o.Namespace)
+
+			// Let's wait the Pod has completed all the tasks before removing roles, as it may cause
+			// problems during the shutdown
+
+			pod := platform.GetOperatorPod(o.Context, c, o.Namespace)
+			if pod != nil {
+				tctx, cancel := context.WithTimeout(o.Context, 15*time.Second)
+				defer cancel()
+				err := watch.WaitPodToTerminate(tctx, c, pod)
+				if err != nil {
+					return fmt.Errorf("error while waiting the operator pod to terminate gracefully: %w", err)
+				}
+			}
 		}
 
 		if err = o.uninstallNamespaceRoles(o.Context, cmd, c); err != nil {
@@ -236,6 +254,12 @@ func (o *uninstallCmdOptions) uninstallNamespaceRoles(ctx context.Context, cmd *
 			return err
 		}
 		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Role Bindings removed from namespace", o.Namespace)
+
+		KEP1755Namespace := "kube-public"
+		if err := o.uninstallKEP1755RoleBindings(ctx, c, KEP1755Namespace); err != nil {
+			return err
+		}
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Role Bindings removed from namespace", KEP1755Namespace)
 	}
 
 	if !o.SkipRoles {
@@ -277,6 +301,13 @@ func (o *uninstallCmdOptions) uninstallNamespaceResources(ctx context.Context, c
 		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Platform Kamelets removed from namespace", o.Namespace)
 	}
 
+	if !o.SkipCamelCatalogs {
+		if err := o.uninstallCamelCatalogs(ctx, c); err != nil {
+			return err
+		}
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Platform Camel Catalogs removed from namespace", o.Namespace)
+	}
+
 	return nil
 }
 
@@ -337,6 +368,24 @@ func (o *uninstallCmdOptions) uninstallRoleBindings(ctx context.Context, c clien
 	return nil
 }
 
+func (o *uninstallCmdOptions) uninstallKEP1755RoleBindings(ctx context.Context, c client.Client, namespace string) error {
+	api := c.RbacV1()
+
+	roleBindings, err := api.RoleBindings(namespace).List(ctx, defaultListOptions)
+	if err != nil {
+		return err
+	}
+
+	for _, roleBinding := range roleBindings.Items {
+		err := api.RoleBindings(namespace).Delete(ctx, roleBinding.Name, metav1.DeleteOptions{})
+		if err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
 func (o *uninstallCmdOptions) uninstallClusterRoles(ctx context.Context, c client.Client) error {
 	api := c.RbacV1()
 
@@ -469,14 +518,14 @@ func (o *uninstallCmdOptions) uninstallRegistrySecret(ctx context.Context, c cli
 }
 
 func (o *uninstallCmdOptions) uninstallKamelets(ctx context.Context, c client.Client) error {
-	kameletList := v1alpha1.NewKameletList()
+	kameletList := v1.NewKameletList()
 	if err := c.List(ctx, &kameletList, ctrl.InNamespace(o.Namespace)); err != nil {
 		return err
 	}
 
 	for i := range kameletList.Items {
 		// remove only platform Kamelets (user-defined Kamelets should be skipped)
-		if kameletList.Items[i].Labels[v1alpha1.KameletBundledLabel] == "true" {
+		if kameletList.Items[i].Labels[v1.KameletBundledLabel] == "true" {
 			err := c.Delete(ctx, &kameletList.Items[i])
 			if err != nil {
 				return err
@@ -487,6 +536,22 @@ func (o *uninstallCmdOptions) uninstallKamelets(ctx context.Context, c client.Cl
 	return nil
 }
 
+func (o *uninstallCmdOptions) uninstallCamelCatalogs(ctx context.Context, c client.Client) error {
+	camelCatalogList := v1.NewCamelCatalogList()
+	if err := c.List(ctx, &camelCatalogList, ctrl.InNamespace(o.Namespace)); err != nil {
+		return err
+	}
+
+	for i := range camelCatalogList.Items {
+		err := c.Delete(ctx, &camelCatalogList.Items[i])
+		if err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
 func createActionNotAuthorizedError(cmd *cobra.Command) error {
 	fmt.Fprintln(cmd.ErrOrStderr(), "Current user is not authorized to remove cluster-wide objects like custom resource definitions or cluster roles")
 	msg := `login as cluster-admin and execute "kamel uninstall" or use flags "--skip-crd --skip-cluster-roles --skip-cluster-role-bindings"`
