@@ -21,8 +21,12 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/apache/camel-k/pkg/util/defaults"
-	"github.com/apache/camel-k/pkg/util/test"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/platform"
+	"k8s.io/apimachinery/pkg/runtime"
+
+	"github.com/apache/camel-k/v2/pkg/util/defaults"
+	"github.com/apache/camel-k/v2/pkg/util/test"
 	"github.com/spf13/cobra"
 	"github.com/stretchr/testify/assert"
 )
@@ -30,10 +34,12 @@ import (
 const cmdVersion = "version"
 
 // nolint: unparam
-func initializeVersionCmdOptions(t *testing.T) (*versionCmdOptions, *cobra.Command, RootCmdOptions) {
+func initializeVersionCmdOptions(t *testing.T, initObjs ...runtime.Object) (*versionCmdOptions, *cobra.Command, RootCmdOptions) {
 	t.Helper()
 
-	options, rootCmd := kamelTestPreAddCommandInit()
+	fakeClient, err := test.NewFakeClient(initObjs...)
+	assert.Nil(t, err)
+	options, rootCmd := kamelTestPreAddCommandInitWithClient(fakeClient)
 	versionCmdOptions := addTestVersionCmd(*options, rootCmd)
 	kamelTestPostAddCommandInit(t, rootCmd)
 
@@ -76,6 +82,30 @@ func TestVersionClientVerbose(t *testing.T) {
 	assert.Equal(t, fmt.Sprintf("Camel K Client %s\nGit Commit: %s\n", defaults.Version, defaults.GitCommit), output)
 }
 
+func TestOperatorVersionVerbose(t *testing.T) {
+	platform := v1.NewIntegrationPlatform("default", platform.DefaultPlatformName)
+	platform.Status.Version = defaults.Version
+	platform.Status.Build.RuntimeVersion = defaults.DefaultRuntimeVersion
+	platform.Status.Phase = v1.IntegrationPlatformPhaseReady
+	catalog := v1.NewCamelCatalog(platform.Namespace, defaults.DefaultRuntimeVersion)
+	catalog.Spec = v1.CamelCatalogSpec{Runtime: v1.RuntimeSpec{Provider: platform.Status.Build.RuntimeProvider, Version: platform.Status.Build.RuntimeVersion}}
+	// mocked catalog versions
+	catalog.Spec.Runtime.Metadata = map[string]string{
+		"camel-quarkus.version": "2.16.0",
+		"camel.version":         "3.20.1",
+		"quarkus.version":       "2.16.0.Final",
+	}
+
+	versionCmdOptions, rootCmd, _ := initializeVersionCmdOptions(t, &platform, &catalog)
+	output, err := test.ExecuteCommand(rootCmd, cmdVersion, "-v", "--operator")
+	assert.Nil(t, err)
+	assert.Equal(t, true, versionCmdOptions.Verbose)
+	assert.Contains(t, output, fmt.Sprintf("Camel K Operator %s\n", defaults.Version))
+	assert.Contains(t, output, fmt.Sprintf("Camel version: %s\n", catalog.Spec.Runtime.Metadata["camel.version"]))
+	assert.Contains(t, output, fmt.Sprintf("Camel Quarkus version: %s\n", catalog.Spec.Runtime.Metadata["camel-quarkus.version"]))
+	assert.Contains(t, output, fmt.Sprintf("Quarkus version: %s\n", catalog.Spec.Runtime.Metadata["quarkus.version"]))
+}
+
 func TestCompatibleVersions(t *testing.T) {
 	_, rootCmd, _ := initializeVersionCmdOptions(t)
 	assert.Equal(t, true, compatibleVersions("1.3.0", "1.3.0", rootCmd))
@@ -86,3 +116,9 @@ func TestCompatibleVersions(t *testing.T) {
 	assert.Equal(t, false, compatibleVersions("1.3.0", "dsadsa", rootCmd))
 	assert.Equal(t, false, compatibleVersions("dsadsa", "1.3.4", rootCmd))
 }
+
+func TestCompatibleVersionsNonSemver(t *testing.T) {
+	_, rootCmd, _ := initializeVersionCmdOptions(t)
+	assert.Equal(t, true, compatibleVersions("1.3.0.special-version", "1.3.0.special-version", rootCmd))
+	assert.Equal(t, false, compatibleVersions("1.3.1.special-version", "1.3.0.special-version", rootCmd))
+}
