@@ -19,24 +19,25 @@ package integrationkit
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"strings"
 	"time"
 
-	"github.com/apache/camel-k/pkg/util/defaults"
-	"github.com/pkg/errors"
+	"github.com/apache/camel-k/v2/pkg/util/defaults"
 
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/trait"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/apache/camel-k/v2/pkg/trait"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
 )
 
-// NewBuildAction creates a new build request handling action for the kit
+// NewBuildAction creates a new build request handling action for the kit.
 func NewBuildAction() Action {
 	return &buildAction{}
 }
@@ -51,11 +52,13 @@ func (action *buildAction) Name() string {
 
 func (action *buildAction) CanHandle(kit *v1.IntegrationKit) bool {
 	return kit.Status.Phase == v1.IntegrationKitPhaseBuildSubmitted ||
-		kit.Status.Phase == v1.IntegrationKitPhaseBuildRunning
+		kit.Status.Phase == v1.IntegrationKitPhaseBuildRunning ||
+		kit.Status.Phase == v1.IntegrationKitPhaseWaitingForCatalog
 }
 
 func (action *buildAction) Handle(ctx context.Context, kit *v1.IntegrationKit) (*v1.IntegrationKit, error) {
-	if kit.Status.Phase == v1.IntegrationKitPhaseBuildSubmitted {
+	if kit.Status.Phase == v1.IntegrationKitPhaseBuildSubmitted ||
+		kit.Status.Phase == v1.IntegrationKitPhaseWaitingForCatalog {
 		return action.handleBuildSubmitted(ctx, kit)
 	} else if kit.Status.Phase == v1.IntegrationKitPhaseBuildRunning {
 		return action.handleBuildRunning(ctx, kit)
@@ -103,6 +106,36 @@ func (action *buildAction) handleBuildSubmitted(ctx context.Context, kit *v1.Int
 				Duration: 10 * time.Minute,
 			}
 		}
+
+		// We may need to change certain builder configuration values
+		operatorNamespace := platform.GetOperatorNamespace()
+		buildConfig := v1.BuilderConfigurationTasks(env.Pipeline)
+		if buildConfig.IsEmpty() {
+			// default to IntegrationPlatform configuration
+			buildConfig = &env.Platform.Status.Build.BuildConfiguration
+		} else {
+			if buildConfig.Strategy == "" {
+				// we always need to define a strategy, so we default to platform if none
+				buildConfig.Strategy = env.Platform.Status.Build.BuildConfiguration.Strategy
+			}
+
+			if buildConfig.OrderStrategy == "" {
+				// we always need to define an order strategy, so we default to platform if none
+				buildConfig.OrderStrategy = env.Platform.Status.Build.BuildConfiguration.OrderStrategy
+			}
+		}
+
+		// nolint: contextcheck
+		if buildConfig.Strategy == v1.BuildStrategyPod {
+			err = platform.CreateBuilderServiceAccount(env.Ctx, env.Client, env.Platform)
+			if err != nil {
+				return nil, fmt.Errorf("error while creating Camel K Builder service account: %w", err)
+			}
+		}
+		buildConfig.ToolImage = env.CamelCatalog.Image
+		buildConfig.BuilderPodNamespace = operatorNamespace
+		v1.SetBuilderConfigurationTasks(env.Pipeline, buildConfig)
+
 		build = &v1.Build{
 			TypeMeta: metav1.TypeMeta{
 				APIVersion: v1.SchemeGroupVersion.String(),
@@ -115,9 +148,8 @@ func (action *buildAction) handleBuildSubmitted(ctx context.Context, kit *v1.Int
 				Annotations: annotations,
 			},
 			Spec: v1.BuildSpec{
-				Strategy: env.Platform.Status.Build.BuildStrategy,
-				Tasks:    env.BuildTasks,
-				Timeout:  timeout,
+				Tasks:   env.Pipeline,
+				Timeout: timeout,
 			},
 		}
 
@@ -128,12 +160,12 @@ func (action *buildAction) handleBuildSubmitted(ctx context.Context, kit *v1.Int
 
 		err = action.client.Delete(ctx, build)
 		if err != nil && !k8serrors.IsNotFound(err) {
-			return nil, errors.Wrap(err, "cannot delete build")
+			return nil, fmt.Errorf("cannot delete build: %w", err)
 		}
 
 		err = action.client.Create(ctx, build)
 		if err != nil {
-			return nil, errors.Wrap(err, "cannot create build")
+			return nil, fmt.Errorf("cannot create build: %w", err)
 		}
 	}
 
