@@ -19,7 +19,8 @@ package resources
 
 import (
 	"bytes"
-	"io/ioutil"
+	"fmt"
+	"io"
 	"net/http"
 	"os"
 	"path"
@@ -27,15 +28,14 @@ import (
 	"strings"
 	"text/template"
 
-	"github.com/apache/camel-k/pkg/util"
-
-	"github.com/pkg/errors"
+	"github.com/apache/camel-k/v2/pkg/util"
 )
 
-//
-//go:generate go run ../../cmd/util/vfs-gen resources config
 //
 // ResourceAsString returns the named resource content as string.
+// Warning : do not remove the go:generate line as it is used to update the resources file in case of CRD changes.
+//
+//go:generate go run ../../cmd/util/vfs-gen resources config
 func ResourceAsString(name string) (string, error) {
 	data, err := Resource(name)
 	return string(data), err
@@ -51,13 +51,13 @@ func Resource(name string) ([]byte, error) {
 
 	file, err := openAsset(name)
 	if err != nil {
-		return nil, errors.Wrapf(err, "cannot access resource file %s", name)
+		return nil, fmt.Errorf("cannot access resource file %s: %w", name, err)
 	}
 
-	data, err := ioutil.ReadAll(file)
+	data, err := io.ReadAll(file)
 	if err != nil {
 		_ = file.Close()
-		return nil, errors.Wrapf(err, "cannot access resource file %s", name)
+		return nil, fmt.Errorf("cannot access resource file %s: %w", name, err)
 	}
 
 	return data, file.Close()
@@ -124,7 +124,7 @@ func Resources(dirName string) ([]string, error) {
 			return nil, nil
 		}
 
-		return nil, errors.Wrapf(err, "error while listing resource files %s", dirName)
+		return nil, fmt.Errorf("error while listing resource files %s: %w", dirName, err)
 	}
 
 	info, err := dir.Stat()
@@ -133,13 +133,13 @@ func Resources(dirName string) ([]string, error) {
 	}
 	if !info.IsDir() {
 		util.CloseQuietly(dir)
-		return nil, errors.Wrapf(err, "location %s is not a directory", dirName)
+		return nil, fmt.Errorf("location %s is not a directory: %w", dirName, err)
 	}
 
 	files, err := dir.Readdir(-1)
 	if err != nil {
 		util.CloseQuietly(dir)
-		return nil, errors.Wrapf(err, "error while listing files on directory %s", dirName)
+		return nil, fmt.Errorf("error while listing files on directory %s: %w", dirName, err)
 	}
 
 	var res []string
