@@ -19,23 +19,24 @@ package trait
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"strconv"
 	"strings"
 
-	"github.com/pkg/errors"
-
 	corev1 "k8s.io/api/core/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/utils/pointer"
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
-	"github.com/apache/camel-k/pkg/util/camel"
-	"github.com/apache/camel-k/pkg/util/maven"
-	"github.com/apache/camel-k/pkg/util/property"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/maven"
+	"github.com/apache/camel-k/v2/pkg/util/property"
 )
 
 type camelTrait struct {
@@ -59,6 +60,11 @@ func (t *camelTrait) InfluencesKit() bool {
 	return true
 }
 
+// InfluencesBuild only when the runtime has changed.
+func (t *camelTrait) InfluencesBuild(this, prev map[string]interface{}) bool {
+	return this["runtimeVersion"] != prev["runtimeVersion"]
+}
+
 func (t *camelTrait) Configure(e *Environment) (bool, error) {
 	if !pointer.BoolDeref(t.Enabled, true) {
 		return false, errors.New("trait camel cannot be disabled")
@@ -132,7 +138,7 @@ func (t *camelTrait) loadOrCreateCatalog(e *Environment, runtimeVersion string)
 			}
 
 			// sanitize catalog name
-			catalogName := "camel-catalog-" + strings.ToLower(runtimeVersion) + "-" + string(runtime.Provider)
+			catalogName := "camel-catalog-" + strings.ToLower(runtimeVersion)
 
 			cx := v1.NewCamelCatalogWithSpecs(ns, catalogName, catalog.CamelCatalogSpec)
 			cx.Labels = make(map[string]string)
@@ -149,15 +155,31 @@ func (t *camelTrait) loadOrCreateCatalog(e *Environment, runtimeVersion string)
 					catalog, err = camel.LoadCatalog(e.Ctx, e.Client, ns, runtime)
 					if err != nil {
 						// unexpected error
-						return errors.Wrapf(err, "catalog %q already exists but unable to load", catalogName)
+						return fmt.Errorf("catalog %q already exists but unable to load: %w", catalogName, err)
 					}
 				} else {
-					return errors.Wrapf(err, "unable to create catalog runtime=%s, provider=%s, name=%s",
+					return fmt.Errorf("unable to create catalog runtime=%s, provider=%s, name=%s: %w",
 						runtime.Version,
 						runtime.Provider,
-						catalogName)
+						catalogName, err)
+
 				}
 			}
+
+			// verify that the catalog was generated
+			ct, err := kubernetes.GetUnstructured(
+				e.Ctx,
+				e.Client,
+				schema.GroupVersionKind{Group: "camel.apache.org", Version: "v1", Kind: "CamelCatalog"},
+				catalogName,
+				e.Integration.Namespace,
+			)
+			if ct == nil || err != nil {
+				return fmt.Errorf("unable to create catalog runtime=%s, provider=%s, name=%s: %w",
+					runtime.Version,
+					runtime.Provider,
+					catalogName, err)
+			}
 		}
 	}
 
