@@ -25,7 +25,7 @@ import (
 
 	servingv1 "knative.dev/serving/pkg/apis/serving/v1"
 
-	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 )
 
 type istioTrait struct {
