@@ -24,7 +24,6 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/scylladb/go-set/strset"
 	"github.com/stretchr/testify/assert"
 
 	appsv1 "k8s.io/api/apps/v1"
@@ -34,11 +33,12 @@ import (
 
 	serving "knative.dev/serving/pkg/apis/serving/v1"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/builder"
-	"github.com/apache/camel-k/pkg/util/camel"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
-	"github.com/apache/camel-k/pkg/util/test"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/builder"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/sets"
+	"github.com/apache/camel-k/v2/pkg/util/test"
 )
 
 var (
@@ -109,7 +109,9 @@ func TestApplyJvmTraitWithDeploymentResource(t *testing.T) {
 
 	assert.Nil(t, err)
 
-	cp := strset.New("./resources", crMountPath, rdMountPath, "/mount/path").List()
+	s := sets.NewSet()
+	s.Add("./resources", crMountPath, rdMountPath, "/mount/path")
+	cp := s.List()
 	sort.Strings(cp)
 
 	assert.Equal(t, []string{
@@ -141,7 +143,9 @@ func TestApplyJvmTraitWithKNativeResource(t *testing.T) {
 
 	assert.Nil(t, err)
 
-	cp := strset.New("./resources", crMountPath, rdMountPath, "/mount/path").List()
+	st := sets.NewSet()
+	st.Add("./resources", crMountPath, rdMountPath, "/mount/path")
+	cp := st.List()
 	sort.Strings(cp)
 
 	assert.Equal(t, []string{
