@@ -25,8 +25,6 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/pkg/errors"
-
 	appsv1 "k8s.io/api/apps/v1"
 	batchv1 "k8s.io/api/batch/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -34,14 +32,14 @@ import (
 
 	serving "knative.dev/serving/pkg/apis/serving/v1"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/platform"
-	"github.com/apache/camel-k/pkg/util"
-	"github.com/apache/camel-k/pkg/util/camel"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
-	"github.com/apache/camel-k/pkg/util/log"
-	"github.com/apache/camel-k/pkg/util/property"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/v2/pkg/client"
+	"github.com/apache/camel-k/v2/pkg/platform"
+	"github.com/apache/camel-k/v2/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/util/camel"
+	"github.com/apache/camel-k/v2/pkg/util/kubernetes"
+	"github.com/apache/camel-k/v2/pkg/util/log"
+	"github.com/apache/camel-k/v2/pkg/util/property"
 )
 
 const (
@@ -71,6 +69,11 @@ type Trait interface {
 	// InfluencesKit determines if the trait has any influence on Integration Kits
 	InfluencesKit() bool
 
+	// InfluencesBuild defines a low level of granularity for those traits which influences the build.
+	// The trait can specify if any particular trait configuration influences a build or not.
+	// Note: You must override this method if you override `InfluencesKit()`
+	InfluencesBuild(this, prev map[string]interface{}) bool
+
 	// IsPlatformTrait marks all fundamental traits that allow the platform to work
 	IsPlatformTrait() bool
 
@@ -137,6 +140,12 @@ func (trait *BaseTrait) InfluencesKit() bool {
 	return false
 }
 
+// InfluencesBuild defines a low level of granularity for those traits which influences the build.
+// The trait can specify if any particular trait configuration influences a build or not.
+func (trait *BaseTrait) InfluencesBuild(this, prev map[string]interface{}) bool {
+	return false
+}
+
 // IsPlatformTrait marks all fundamental traits that allow the platform to work.
 func (trait *BaseTrait) IsPlatformTrait() bool {
 	return false
@@ -189,7 +198,7 @@ type Environment struct {
 	PostActions           []func(*Environment) error
 	PostStepProcessors    []func(*Environment) error
 	PostProcessors        []func(*Environment) error
-	BuildTasks            []v1.Task
+	Pipeline              []v1.Task
 	ConfiguredTraits      []Trait
 	ExecutedTraits        []Trait
 	EnvVars               []corev1.EnvVar
@@ -375,7 +384,7 @@ func (e *Environment) computeApplicationProperties() (*corev1.ConfigMap, error)
 	// application properties
 	applicationProperties, err := property.EncodePropertyFile(e.ApplicationProperties)
 	if err != nil {
-		return nil, errors.Wrapf(err, "could not compute application properties")
+		return nil, fmt.Errorf("could not compute application properties: %w", err)
 	}
 
 	if applicationProperties != "" {
