@@ -19,35 +19,32 @@ package bindings
 
 import (
 	"context"
-	"encoding/json"
 	"fmt"
-	"net/url"
 	"testing"
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/utils/pointer"
 
-	camelv1 "github.com/apache/camel-k/pkg/apis/camel/v1"
-	knativeapis "github.com/apache/camel-k/pkg/apis/camel/v1/knative"
-	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
-	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
-	"github.com/apache/camel-k/pkg/util/test"
+	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
+
+	"github.com/apache/camel-k/v2/pkg/util/test"
 
 	"github.com/stretchr/testify/assert"
 )
 
 func TestBindings(t *testing.T) {
 	testcases := []struct {
-		endpointType v1alpha1.EndpointType
-		endpoint     v1alpha1.Endpoint
-		profile      camelv1.TraitProfile
+		endpointType v1.EndpointType
+		endpoint     v1.Endpoint
+		profile      v1.TraitProfile
 		uri          string
-		traits       camelv1.Traits
+		traits       v1.Traits
 		props        map[string]string
 	}{
 		{
-			endpointType: v1alpha1.EndpointTypeSink,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSink,
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Service",
 					APIVersion: "serving.knative.dev/v1",
@@ -57,8 +54,8 @@ func TestBindings(t *testing.T) {
 			uri: "knative:endpoint/myservice?apiVersion=serving.knative.dev%2Fv1&kind=Service",
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeAction,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeAction,
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Service",
 					APIVersion: "serving.knative.dev/v1",
@@ -68,8 +65,8 @@ func TestBindings(t *testing.T) {
 			uri: "knative:endpoint/myservice?apiVersion=serving.knative.dev%2Fv1&kind=Service",
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSink,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSink,
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Service",
 					APIVersion: "serving.knative.dev/v1",
@@ -82,8 +79,8 @@ func TestBindings(t *testing.T) {
 			uri: "knative:endpoint/myservice?apiVersion=serving.knative.dev%2Fv1&ce.override.ce-type=mytype&kind=Service",
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSink,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSink,
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Channel",
 					APIVersion: "messaging.knative.dev/v1",
@@ -93,8 +90,8 @@ func TestBindings(t *testing.T) {
 			uri: "knative:channel/mychannel?apiVersion=messaging.knative.dev%2Fv1&kind=Channel",
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSource,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSource,
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Channel",
 					APIVersion: "messaging.knative.dev/v1",
@@ -104,8 +101,8 @@ func TestBindings(t *testing.T) {
 			uri: "knative:channel/mychannel?apiVersion=messaging.knative.dev%2Fv1&kind=Channel",
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSource,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSource,
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "KafkaChannel",
 					APIVersion: "messaging.knative.dev/v1beta1",
@@ -115,8 +112,8 @@ func TestBindings(t *testing.T) {
 			uri: "knative:channel/mychannel?apiVersion=messaging.knative.dev%2Fv1beta1&kind=KafkaChannel",
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSource,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSource,
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Broker",
 					APIVersion: "eventing.knative.dev/v1",
@@ -129,19 +126,20 @@ func TestBindings(t *testing.T) {
 			uri: "knative:event/myeventtype?apiVersion=eventing.knative.dev%2Fv1&kind=Broker&name=default",
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSource,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSource,
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Kamelet",
 					APIVersion: "camel.apache.org/v1any1",
 					Name:       "mykamelet",
 				},
 			},
-			uri: "kamelet:mykamelet/source",
+			uri:   "kamelet:mykamelet/source",
+			props: map[string]string{},
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSink,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSink,
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Kamelet",
 					APIVersion: "camel.apache.org/v1any1",
@@ -159,7 +157,7 @@ func TestBindings(t *testing.T) {
 			},
 		},
 		{
-			endpoint: v1alpha1.Endpoint{
+			endpoint: v1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Kamelet",
 					APIVersion: "camel.apache.org/v1any1",
@@ -176,15 +174,15 @@ func TestBindings(t *testing.T) {
 			},
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSink,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSink,
+			endpoint: v1.Endpoint{
 				URI: pointer.String("https://myurl/hey"),
 				Properties: asEndpointProperties(map[string]string{
 					"ce.override.ce-type": "mytype",
 				}),
 			},
 			uri: "knative:endpoint/sink?ce.override.ce-type=mytype",
-			traits: camelv1.Traits{
+			traits: v1.Traits{
 				Knative: &traitv1.KnativeTrait{
 					SinkBinding:   pointer.Bool(false),
 					Configuration: asKnativeConfig("https://myurl/hey"),
@@ -192,16 +190,16 @@ func TestBindings(t *testing.T) {
 			},
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSink,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSink,
+			endpoint: v1.Endpoint{
 				URI: pointer.String("https://myurl/hey"),
 			},
-			profile: camelv1.TraitProfileKubernetes,
+			profile: v1.TraitProfileKubernetes,
 			uri:     "https://myurl/hey",
 		},
 		{
-			endpointType: v1alpha1.EndpointTypeSink,
-			endpoint: v1alpha1.Endpoint{
+			endpointType: v1.EndpointTypeSink,
+			endpoint: v1.Endpoint{
 				URI: pointer.String("docker://xxx"),
 			},
 			uri: "docker://xxx",
@@ -218,7 +216,7 @@ func TestBindings(t *testing.T) {
 
 			profile := tc.profile
 			if profile == "" {
-				profile = camelv1.TraitProfileKnative
+				profile = v1.TraitProfileKnative
 			}
 
 			bindingContext := BindingContext{
@@ -239,31 +237,3 @@ func TestBindings(t *testing.T) {
 		})
 	}
 }
-
-func asEndpointProperties(props map[string]string) *v1alpha1.EndpointProperties {
-	serialized, err := json.Marshal(props)
-	if err != nil {
-		panic(err)
-	}
-	return &v1alpha1.EndpointProperties{
-		RawMessage: serialized,
-	}
-}
-
-func asKnativeConfig(endpointURL string) string {
-	serviceURL, err := url.Parse(endpointURL)
-	if err != nil {
-		panic(err)
-	}
-	def, err := knativeapis.BuildCamelServiceDefinition("sink", knativeapis.CamelEndpointKindSink, knativeapis.CamelServiceTypeEndpoint, *serviceURL, "", "")
-	if err != nil {
-		panic(err)
-	}
-	env := knativeapis.NewCamelEnvironment()
-	env.Services = append(env.Services, def)
-	serialized, err := json.Marshal(env)
-	if err != nil {
-		panic(err)
-	}
-	return string(serialized)
-}
