@@ -23,7 +23,7 @@ import (
 	"os/exec"
 	"testing"
 
-	"github.com/apache/camel-k/pkg/util"
+	"github.com/apache/camel-k/v2/pkg/util"
 	"github.com/stretchr/testify/assert"
 )
 
